==> hbase-1.7.1-src.tar.gz: hbase-1.7.1/hbase-server/src/test/java/org/apache/hadoop/hbase/regionserver/KeyValueScanFixture.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.regionserver;

import org.apache.hadoop.hbase.regionserver.KeyValueScanner;
import org.apache.hadoop.hbase.util.CollectionBackedScanner;
import org.apache.hadoop.hbase.KeyValue;

import java.util.ArrayList;
import java.util.List;

/**
 * A fixture that implements and presents a KeyValueScanner.
 * It takes a list of key/values which is then sorted according
 * to the provided comparator, and then the whole thing pretends
 * to be a store file scanner.
 */
public class KeyValueScanFixture extends CollectionBackedScanner {
  public KeyValueScanFixture(KeyValue.KVComparator comparator, KeyValue... incData) {
    super(comparator, incData);
  }

  public static List<KeyValueScanner> scanFixture(KeyValue[] ... kvArrays) {
    ArrayList<KeyValueScanner> scanners = new ArrayList<KeyValueScanner>();
    for (KeyValue [] kvs : kvArrays) {
      scanners.add(new KeyValueScanFixture(KeyValue.COMPARATOR, kvs));
    }
    return scanners;
  }
}

==> hbase-2.3.7-src.tar.gz: hbase-2.3.7/hbase-server/src/test/java/org/apache/hadoop/hbase/regionserver/KeyValueScanFixture.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.regionserver;

import java.util.ArrayList;
import java.util.List;

import org.apache.hadoop.hbase.Cell;
import org.apache.hadoop.hbase.CellComparator;
import org.apache.hadoop.hbase.KeyValue;
import org.apache.hadoop.hbase.util.CollectionBackedScanner;

/**
 * A fixture that implements and presents a KeyValueScanner.
 * It takes a list of key/values which is then sorted according
 * to the provided comparator, and then the whole thing pretends
 * to be a store file scanner.
 */
public class KeyValueScanFixture extends CollectionBackedScanner {
  public KeyValueScanFixture(CellComparator comparator, Cell... cells) {
    super(comparator, cells);
  }

  public static List<KeyValueScanner> scanFixture(KeyValue[] ... kvArrays) {
    ArrayList<KeyValueScanner> scanners = new ArrayList<>();
    for (KeyValue [] kvs : kvArrays) {
      scanners.add(new KeyValueScanFixture(CellComparator.getInstance(), kvs));
    }
    return scanners;
  }
}
